@@ -5,7 +5,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2019-2024 Univention GmbH
+# Copyright 2019-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -182,7 +182,7 @@ class UMCAndSecretAuthenticator(UMCAuthenticator):
         username = display_name.lower()
         get_logger("user").debug("received basic auth request with username=%r", username)
         try:
-            with open(config.fetch("portal-secret-file")) as fd:  # noqa: ASYNC101
+            with open(config.fetch("portal-secret-file")) as fd:  # noqa: ASYNC221, ASYNC230
                 config_secret = fd.read().strip()
         except (KeyError, AttributeError):
             return user
