@@ -5,7 +5,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2020-2024 Univention GmbH
+# Copyright 2020-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -51,7 +51,7 @@ class TestUMCAuthenticator:
     _username = "TestUser"
     _groups = ["TestGroup"]
 
-    @pytest.fixture()
+    @pytest.fixture
     def mocked_authenticator(self, dynamic_class, patch_object_module, mocker):
         Authenticator = dynamic_class("UMCAuthenticator")
         mocked_group_cache = mocker.Mock()
