@@ -1,7 +1,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# SPDX-FileCopyrightText: 2024 Univention GmbH
+# SPDX-FileCopyrightText: 2024-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 from unittest import mock
@@ -11,7 +11,7 @@ import pytest
 from univention.portal.extensions.portal import UMCPortal
 
 
-@pytest.fixture()
+@pytest.fixture
 def stub_module():
     """A stub module as returned from the UMC API."""
     return {
@@ -28,7 +28,7 @@ def stub_module():
     }
 
 
-@pytest.fixture()
+@pytest.fixture
 def stub_visible_content(stub_module):
     """
     A stub of the datastructure which is returned by `UMCPortal.get_visible_content`.
@@ -47,7 +47,7 @@ def stub_visible_content(stub_module):
     }
 
 
-@pytest.fixture()
+@pytest.fixture
 def umc_portal():
     """An instance of UMCPortal with mocked dependencies."""
     umc_portal = UMCPortal(mock.Mock(), mock.Mock())
